'use client';
var jsxRuntime = require('react/jsx-runtime');
var ExpandMoreIcon = require('@mui/icons-material/ExpandMore');
var material = require('@mui/material');
var React = require('react');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var ExpandMoreIcon__default = /*#__PURE__*/_interopDefault(ExpandMoreIcon);

const CollapsibleContext = /*#__PURE__*/ React.createContext(null);
const useCollapsible = ()=>{
    const context = React.useContext(CollapsibleContext);
    if (!context) {
        throw new Error('useCollapsible must be used within a CollapsibleProvider.');
    }
    return context;
};
/**
 * `Collapsible` 一個可以透過觸發按鈕展開或收起區塊，跟 `Accordion` 的差別在於 `Collapsible` 可以自由控制開關。
 *
 * ref: https://mui.com/material-ui/api/collapse/
 *
 * @example
 *
 * ```tsx
 * <Collapsible>
 *  <CollapsibleTrigger>
 *    <Button>Toggle</Button>
 *  </CollapsibleTrigger>
 *  <CollapsibleContent>
 *    <div>Content</div>
 *  </CollapsibleContent>
 * </Collapsible>
 * ```
 */ const Collapsible = ({ children, defaultOpen = true, open: outerOpen, onOpenChange: setOuterOpen })=>{
    // This is the internal state of the Collapsible.
    // We use outerOpen and setOuterOpen for control from outside the component.
    const [innerOpen, setInnerOpen] = React.useState(defaultOpen);
    const open = outerOpen ?? innerOpen;
    const setOpen = React.useCallback((value)=>{
        const openState = typeof value === 'function' ? value(open) : value;
        if (setOuterOpen) {
            setOuterOpen(openState);
        } else {
            setInnerOpen(openState);
        }
    }, [
        setOuterOpen,
        open
    ]);
    // Helper to toggle the Collapsible.
    const toggleCollapsible = React.useCallback(()=>setOpen((preOpen)=>!preOpen), [
        setOpen
    ]);
    const contextValue = React.useMemo(()=>({
            open,
            setOpen,
            toggleCollapsible
        }), [
        open,
        setOpen,
        toggleCollapsible
    ]);
    return /*#__PURE__*/ jsxRuntime.jsx(CollapsibleContext.Provider, {
        value: contextValue,
        children: children
    });
};
const CollapsibleTrigger = ({ children })=>{
    const anchorRef = React.useRef(null);
    const element = React.Children.only(children);
    const { toggleCollapsible } = useCollapsible();
    if (/*#__PURE__*/ React.isValidElement(children)) {
        return /*#__PURE__*/ React.cloneElement(element, {
            ref: anchorRef,
            onClick: ()=>{
                element.props.onClick?.();
                toggleCollapsible();
            }
        });
    }
    return React.Children.count(children) > 1 ? React.Children.only(null) : null;
};
const CollapsibleContent = ({ children })=>{
    const { open } = useCollapsible();
    return /*#__PURE__*/ jsxRuntime.jsx(material.Collapse, {
        in: open,
        children: children
    });
};
/**
 * An icon that rotates when the Collapsible is open.
 */ const CollapsibleIcon = ({ sx, ...props })=>{
    const theme = material.useTheme();
    const { open } = useCollapsible();
    return /*#__PURE__*/ jsxRuntime.jsx(ExpandMoreIcon__default.default, {
        sx: {
            transition: theme.transitions.create('transform'),
            transform: open ? 'rotate(180deg)' : 'rotate(0deg)',
            ...sx
        },
        ...props
    });
};

exports.Collapsible = Collapsible;
exports.CollapsibleContent = CollapsibleContent;
exports.CollapsibleIcon = CollapsibleIcon;
exports.CollapsibleTrigger = CollapsibleTrigger;
exports.useCollapsible = useCollapsible;
