import { BreadcrumbsProps as BreadcrumbsProps$1, BoxProps, TypographyProps, CardProps as CardProps$1, CardHeaderProps, CardContentProps, IconButtonProps as IconButtonProps$2, SvgIconProps, DrawerProps as DrawerProps$1, PaperProps, PopperProps, ListProps, FormControlProps, DialogTitleProps, DialogContentProps, DialogActionsProps, DialogProps, Box, Typography, SwipeableDrawerProps, SwitchProps as SwitchProps$1, TextFieldProps as TextFieldProps$2, TextFieldVariants, StackProps } from '@mui/material';
import * as react from 'react';
import react__default from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';
import { ButtonProps as ButtonProps$1 } from '@mui/material/Button';
import { IconButtonProps as IconButtonProps$1 } from '@mui/material/IconButton';
import { TypographyProps as TypographyProps$1 } from '@mui/material/Typography';
import useEmblaCarousel, { UseEmblaCarouselType } from 'embla-carousel-react';
import { BoxProps as BoxProps$1 } from '@mui/material/Box';
import { BackdropProps } from '@mui/material/Backdrop';
import * as material_react_table from 'material-react-table';
import { MRT_TableOptions } from 'material-react-table';
import { NumericFormatProps } from 'react-number-format';
import { AlertProps, AlertColor } from '@mui/material/Alert';
import { SnackbarProps } from '@mui/material/Snackbar';
import { SxProps } from '@mui/material/styles';

type TBreadcrumbsContext = {
    /**
     * if `true`, the current route will be extracted from the children
     * @default false
     */
    extractCurrent?: boolean;
    /**
     * position of the current route
     * @default 'top'
     */
    currentPosition?: 'top' | 'bottom';
};
declare const BreadcrumbsProvider: ({ extractCurrent, currentPosition, children, }: React.PropsWithChildren<TBreadcrumbsContext>) => react_jsx_runtime.JSX.Element;
declare const useBreadcrumbs: () => TBreadcrumbsContext | null;

type BreadcrumbsProps<C extends react.ElementType = 'nav'> = BreadcrumbsProps$1<C, {
    /**
     * The Root Box component props, only available when `extractCurrent` is `true`.
     */
    containerProps?: BoxProps;
    /**
     * The component used for the root node. Either a string to use a HTML element or a component.
     */
    component?: C;
} & TBreadcrumbsContext>;
/**
 * `Breadcrumb` 是一個導航元件，用於顯示當前系統層級結構中的路徑位置。
 *
 * 參考 [Material-UI Breadcrumbs](https://mui.com/material-ui/react-breadcrumbs/)
 *
 * @example
 *
 * ```tsx
 * <Breadcrumbs>
 *  <BreadcrumbItem>Home</BreadcrumbItem>
 *  <BreadcrumbItem>Components</BreadcrumbItem>
 *  <BreadcrumbItem isLast>Button</BreadcrumbItem>
 * </Breadcrumbs>
 *
 * // 也可以自訂子節點元件
 * <Breadcrumbs>
 *  <span>Home</span>
 *  <span>Components</span>
 *  <span>Button</span>
 * </Breadcrumbs>
 * ```
 */
declare const Breadcrumbs: <C extends react.ElementType = "nav">(props: BreadcrumbsProps<C> & {
    ref?: react.ComponentPropsWithRef<C>["ref"];
}) => react.JSX.Element;

type BreadcrumbItemProps<C extends React.ElementType = 'span'> = TypographyProps<C, {
    /**
     * if `true`, the item will be added a loading spinner, and set to disabled
     */
    isLast?: boolean;
    component?: C;
}>;
/**
 * `BreadcrumbItem` 是 `Breadcrumb` 的子元件，用於顯示當前路徑的每一個節點。
 *
 * @example
 *
 * ```tsx
 * <Breadcrumbs>
 *  <BreadcrumbItem>Home</BreadcrumbItem>
 *  <BreadcrumbItem>Components</BreadcrumbItem>
 *  <BreadcrumbItem isLast>Button</BreadcrumbItem>
 * </Breadcrumbs>
 * ```
 */
declare const BreadcrumbItem: <C extends React.ElementType = "span">(props: BreadcrumbItemProps<C> & {
    ref?: React.ComponentPropsWithRef<C>["ref"];
}) => React.JSX.Element;

type ButtonProps<C extends React.ElementType> = ButtonProps$1<C, {
    /**
     * if `true`, the button will be added a loading spinner, and set to disabled
     * @default false
     */
    loading?: boolean;
    /**
     * shape of the button
     * @default 'default'
     */
    shape?: 'default' | 'round';
    /**
     * The component used for the root node. Either a string to use a HTML element or a component.
     */
    component?: C;
}>;
/**
 * 表示一個可點擊的按鈕元件，用於觸發相關的業務邏輯。
 *
 * 參考 [Material-UI Button](https://mui.com/material-ui/react-button/)
 *
 * @example
 *
 *  ```tsx
 * <Button variant="contained">Contained</Button>
 * <Button variant="outlined">Outlined</Button>
 * <Button variant="text">Text</Button>
 * ```
 */
declare const Button: <C extends React.ElementType = "button">(props: ButtonProps<C> & {
    ref?: React.ForwardedRef<HTMLButtonElement>;
}) => React.JSX.Element;

type IconButtonProps<C extends React.ElementType> = IconButtonProps$1<C, {
    /**
     * if `true`, the button will be added a loading spinner, and set to disabled
     * @default false
     */
    loading?: boolean;
    /**
     * The component used for the root node. Either a string to use a HTML element or a component.
     */
    component?: C;
}>;
/**
 * 表示一個可點擊的圖示按鈕元件，用於觸發相關的業務邏輯。
 *
 * 參考
 *  - [Material-UI IconButton](https://mui.com/material-ui/react-button/#icon-button)
 *  - [Material-UI Icons](https://mui.com/material-ui/material-icons/)
 *
 * @example
 *
 * ```tsx
 * <IconButton>
 *  <DeleteIcon fontSize="inherit" />
 * </IconButton>
 * ```
 */
declare const IconButton: <C extends React.ElementType = "button">(props: IconButtonProps<C> & {
    ref?: React.ForwardedRef<HTMLButtonElement>;
}) => React.JSX.Element;

type DecorativeTitleProps = {
    /**
     * If `true`, the title will show loading effect.
     */
    loading?: boolean;
} & TypographyProps$1;
/**
 * `DecorativeTitle` 在標題前加上裝飾線。
 *
 * @example
 *
 * ```tsx
 * <DecorativeTitle>Decorative Title</DecorativeTitle>
 * ```
 */
declare const DecorativeTitle: react.ForwardRefExoticComponent<Omit<DecorativeTitleProps, "ref"> & react.RefAttributes<HTMLSpanElement>>;

type LoadingContentProp = {
    /**
     * The Skeleton count.
     *
     * @default 3
     */
    count?: number;
    /**
     * Each Skeleton height.
     *
     * @default 40
     */
    height?: number;
};
/**
 * 用來顯示載入中的內容，通常用在列表或表格中。
 *
 * 預設會顯示 3 個長條狀 Skeleton 元件。
 *
 * 參考 [Material-UI Skeleton](https://mui.com/material-ui/react-skeleton/)
 */
declare function LoadingContent({ count, height }: LoadingContentProp): react_jsx_runtime.JSX.Element;

type LoadingFullScreenProps = {
    /**
     * The loading indicator of the backdrop.
     *
     * @default
     *
     * ```jsx
     * <CircularProgress />
     * ```
     */
    children?: React.ReactNode;
} & Omit<BackdropProps, 'children'>;
/**
 * `LoadingFullScreen` 全螢幕讀取中，通常用於非同步操作時提示使用者等待。
 *
 * 參考 [Material-UI Backdrop](https://mui.com/material-ui/react-backdrop/)
 */
declare function LoadingFullScreen({ sx, children, ...rest }: LoadingFullScreenProps): react_jsx_runtime.JSX.Element;

type LoadingIndicatorProps = {
    /**
     * 類型
     *
     * @default 'bounce'
     */
    type?: 'bounce' | 'pulse' | 'beat';
    /**
     * 顆數
     *
     * @default 3
     */
    count?: number;
    /**
     * 頻率 (s)
     *
     * @default 0.75
     */
    frequency?: number;
};
/**
 * `LoadingIndicator` 是一個用來顯示載入中的元件。
 */
declare const LoadingIndicator: react.ForwardRefExoticComponent<LoadingIndicatorProps & react.RefAttributes<HTMLDivElement>>;

type CardProps<C extends React.ElementType> = CardProps$1<C, {
    /**
     * The title of the card.
     */
    title?: CardHeaderProps['title'];
    /**
     * The props of the title wrapper `CardHeader` component.
     */
    headerProps?: {
        titleProps?: DecorativeTitleProps;
    } & Omit<CardHeaderProps, 'title' | 'cardActions'>;
    /**
     * The action to display in the card header.
     */
    cardActions?: CardHeaderProps['action'];
    /**
     * If `true`, the children will not be wrapped by `CardContent`.
     *
     * @default false
     */
    disableCardContent?: boolean;
    /**
     * The props of the content wrapper `CardContent` component.
     */
    contentProps?: CardContentProps;
    /**
     * If `true`, the card will show loading effect.
     *
     * @default false
     */
    loading?: boolean;
    /**
     * The options of loading effect.
     */
    loadingOptions?: LoadingContentProp;
    /**
     * The component used for the root node. Either a string to use a HTML element or a component.
     */
    component?: C;
}>;
/**
 * 表示一個卡片元件，用於展示相關的資訊。
 *
 * 參考 [Material-UI Card](https://mui.com/material-ui/react-card/)
 *
 * @example
 *
 * ```tsx
 * <Card title="Card Title">
 *  Card Content
 * </Card>
 * ```
 */
declare const Card: <C extends React.ElementType = "div">(props: CardProps<C> & {
    ref?: React.ForwardedRef<HTMLDivElement>;
}) => React.JSX.Element;

type CarouselApi = UseEmblaCarouselType[1];
type UseCarouselParameters = Parameters<typeof useEmblaCarousel>;
type CarouselOptions = UseCarouselParameters[0];
type CarouselPlugin = UseCarouselParameters[1];
type CarouselProps = {
    opts?: CarouselOptions;
    plugins?: CarouselPlugin;
    orientation?: 'horizontal' | 'vertical';
    setApi?: (api: CarouselApi) => void;
} & BoxProps;
type CarouselContextProps = {
    carouselRef: ReturnType<typeof useEmblaCarousel>[0];
    api: ReturnType<typeof useEmblaCarousel>[1];
    scrollPrev: () => void;
    scrollNext: () => void;
    canScrollPrev: boolean;
    canScrollNext: boolean;
} & CarouselProps;
declare const useCarousel: () => CarouselContextProps;
/**
 * 一個基於 Embla Carousel 的 Carousel 元件，通常用於展示多個元素，並提供左右滑動的功能。
 *
 * 參考 [Embla Carousel](https://www.embla-carousel.com/)
 *
 * @example
 *
 * ```tsx
 * <Carousel>
 *  <CarouselContent>
 *   {Array.from({ length: 5 }).map((_, index) => (
 *    <CarouselItem key={index}>
 *      {index + 1}
 *    </CarouselItem>
 *   ))}
 *  </CarouselContent>
 *  <CarouselPrevious />
 *  <CarouselNext />
 * </Carousel>
 * ```
 */
declare const Carousel: ({ orientation, opts, setApi, plugins, className, children, sx, ...props }: React.ComponentProps<"div"> & CarouselProps) => react_jsx_runtime.JSX.Element;

declare const CarouselContent: ({ sx, children, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;

declare const CarouselItem: ({ sx, children, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;

declare const CarouselPrevious: ({ sx, ...props }: IconButtonProps$2) => react_jsx_runtime.JSX.Element;
declare const CarouselNext: ({ sx, ...props }: IconButtonProps$2) => react_jsx_runtime.JSX.Element;

type TCollapsibleContext = {
    /**
     * If `true`, the Collapsible is open.
     */
    open: boolean;
    /**
     * Set the Collapsible to open or close.
     */
    setOpen: (open: boolean) => void;
    /**
     * Toggle the Collapsible.
     */
    toggleCollapsible: () => void;
};
declare const useCollapsible: () => TCollapsibleContext;
type TCollapsibleProvider = React.PropsWithChildren<{
    /**
     * If `true`, the Collapsible is open by default.
     */
    defaultOpen?: boolean;
    /**
     * Callback fired when the Collapsible is opened or closed.
     */
    onOpenChange?: (open: boolean) => void;
} & Partial<Pick<TCollapsibleContext, 'open'>>>;
/**
 * `Collapsible` 一個可以透過觸發按鈕展開或收起區塊，跟 `Accordion` 的差別在於 `Collapsible` 可以自由控制開關。
 *
 * ref: https://mui.com/material-ui/api/collapse/
 *
 * @example
 *
 * ```tsx
 * <Collapsible>
 *  <CollapsibleTrigger>
 *    <Button>Toggle</Button>
 *  </CollapsibleTrigger>
 *  <CollapsibleContent>
 *    <div>Content</div>
 *  </CollapsibleContent>
 * </Collapsible>
 * ```
 */
declare const Collapsible: ({ children, defaultOpen, open: outerOpen, onOpenChange: setOuterOpen, }: TCollapsibleProvider) => react_jsx_runtime.JSX.Element;
declare const CollapsibleTrigger: ({ children }: {
    children: React.ReactNode;
}) => react.ReactElement<any, string | react.JSXElementConstructor<any>> | null;
declare const CollapsibleContent: ({ children }: {
    children: React.ReactNode;
}) => react_jsx_runtime.JSX.Element;
/**
 * An icon that rotates when the Collapsible is open.
 */
declare const CollapsibleIcon: ({ sx, ...props }: SvgIconProps) => react_jsx_runtime.JSX.Element;

declare const COLORS: readonly ["default", "primary", "secondary", "error", "info", "success", "warning"];
type DotProps = {
    /**
     * color of the dot
     * @default primary
     */
    color?: (string & {}) | (typeof COLORS)[number];
    /**
     * size of the dot in pixels
     * @default 8
     * @unit px
     */
    size?: number;
    /**
     * label of the dot
     */
    label?: string;
    /**
     * placement of the label
     * @default end
     */
    placement?: 'start' | 'end';
};
/**
 * 狀態點元件，用於表示狀態的小圓點，不同顏色表示不同狀態，分別具備不同含義。
 */
declare const Dot: react.ForwardRefExoticComponent<DotProps & react.RefAttributes<unknown>>;

type DrawerProps = {
    /**
     * the title of the drawer.
     */
    title?: react__default.ReactNode;
    /**
     * If `true`, will show the close icon button on the top-right corner.
     *
     * @default true
     */
    showCloseIcon?: boolean;
    /**
     * The props of the title wrapper `Box` component.
     *
     * ref: [Box API](https://mui.com/material-ui/api/box/)
     */
    headerProps?: {
        titleProps?: DecorativeTitleProps;
    } & BoxProps;
    /**
     * If `true`, disable clicking on the backdrop to close the drawer.
     *
     * @default false
     */
    disableBackdropClick?: boolean;
    /**
     * Callback fired when the component requests to be closed.
     *
     * @param event — The event source of the callback.
     * @param reason — Can be: "escapeKeyDown", "backdropClick", "closeButtonClick".
     */
    onClose?: (event: object, reason: 'backdropClick' | 'escapeKeyDown' | 'closeButtonClick') => void;
    /**
     * The props of the content wrapper `Box` component.
     *
     * ref: [Box API](https://mui.com/material-ui/api/box/)
     */
    contentProps?: {
        /**
         * Display the top and bottom dividers.
         *
         * @default true
         */
        dividers?: boolean;
    } & BoxProps;
    /**
     * The props of the actions wrapper `DialogActions` component.
     *
     * ref: [Box API](https://mui.com/material-ui/api/box/)
     */
    actionsProps?: BoxProps;
    /**
     * callback when the submit button is clicked.
     */
    onSubmit?: () => void | Promise<void>;
    /**
     * The text of the submit button.
     *
     * @default 'Submit'
     */
    submitText?: string;
    /**
     * The text of the cancel button.
     *
     * @default 'Cancel'
     */
    cancelText?: string;
    /**
     * Custom actions component.
     */
    customActions?: react__default.ReactNode;
    /**
     * If `true`, the drawer will show loading effect.
     *
     * @default false
     */
    loading?: boolean;
    /**
     * The options of loading effect.
     */
    loadingOptions?: LoadingContentProp;
} & Omit<DrawerProps$1, 'onClose'>;
/**
 * `Drawer` 抽屜元件，由螢幕邊緣滑出的浮動面版，
 * 常見的應用是作為導航用途，例如 Navigation drawers。
 *
 * 參考 [Material-UI Button](https://mui.com/material-ui/react-drawer/)
 */
declare const Drawer: react__default.ForwardRefExoticComponent<Omit<DrawerProps, "ref"> & react__default.RefAttributes<HTMLDivElement>>;

type DropDownProps = {
    /**
     * The content of the component.
     */
    children: React.ReactNode;
    /**
     * The reference element of the anchor.
     */
    anchorRef?: React.RefObject<HTMLElement | null>;
    /**
     *  The callback when close the dropdown.
     */
    onClose?: () => void;
    /**
     * The props of the content, using the same way as Paper.
     */
    paperProps?: PaperProps;
} & Omit<PopperProps, 'anchorEl'>;
/**
 * 用於下拉式區域的 Popper。
 *
 * 參考 [Material-UI Popper](https://mui.com/material-ui/react-popper/)
 *
 * @example
 *
 * ```tsx
 * <Button ref={anchorRef} onClick={() => setOpen(true)}>
 *   Open
 * </Button>
 * <DropDown
 *  open={open}
 *  onClose={() => setOpen(false)}
 *  anchorRef={anchorRef}
 * >
 *  content
 * </DropDown>
 * ```
 */
declare const DropDown: ({ open, anchorRef, onClose, paperProps, children, ...props }: DropDownProps) => react_jsx_runtime.JSX.Element;

type DropDownListProps<T> = {
    /**
     * If `true`, the dropdown is open.
     */
    open?: boolean;
    /**
     * The callback when close the dropdown.
     */
    onClose?: () => void;
    /**
     * The trigger of the component.
     */
    children: React.ReactElement;
    /**
     * The list of items.
     */
    list: Array<T>;
    /**
     * The callback when click the item.
     */
    onItemClick?: (args: T) => void;
    /**
     * The custom render item function.
     */
    renderItem?: (args: T) => React.ReactNode;
    /**
     * The props of the list, using the same way as List.
     */
    listProps?: ListProps;
} & Omit<React.ComponentProps<typeof DropDown>, 'open' | 'onClose' | 'children' | 'anchorRef' | 'anchorEl'>;
/**
 * DropDown的高階元件，通常用於選單的下拉式清單。
 *
 * 參考 [Material-UI Popper](https://mui.com/material-ui/react-popper/)
 *
 * @example
 *
 * ```tsx
 * <DropDownList
 *  list={['Apple', 'Banana', 'Cherry']}
 * >
 *  <Button>open</Button>
 * </DropDownList>
 * ```
 */
declare const DropDownList: <T extends {
    label: string;
} | string>({ list, onItemClick, renderItem, open: openOuter, onClose: onCloseOuter, children, listProps, ...props }: DropDownListProps<T>) => react_jsx_runtime.JSX.Element;

type FormItemProps = {
    /** 內容 */
    children: React.ReactNode;
    /** 標題 */
    label: React.ReactNode;
    /** 錯誤訊息 */
    helperText?: string;
    /** 說明內容 */
    helpInfo?: React.ReactNode;
    /** 最大字數 */
    maxLength?: number;
    /** 當前字數 */
    currentLength?: number;
} & FormControlProps;
/**
 * `FormItem` 讓我們可以將 form input 所需要的共同前後文特性獨立出來管理，
 * 使被 control 的子元件之間的樣式能夠保持一致性。
 * 例如在 form input 元件 `TextField`, `Switch`, `Checkbox` 當中，
 * 將 `label`, `required`, `error` ...等邏輯與樣式獨立出來藉由 FormItem 來管理。
 *
 * 參考 [Material-UI: FormControl](https://mui.com/material-ui/api/form-control/)
 */
declare const FormItem: ({ children, label, helperText, helpInfo, maxLength, currentLength, error, fullWidth, ...rest }: FormItemProps) => react_jsx_runtime.JSX.Element;

type ImageFieldProps = {
    /**
     * The image source to be displayed.
     */
    image?: File | string;
    /**
     * The image name.
     */
    imageName?: string;
    /**
     * The size of the component.
     *
     * @default 'medium'
     */
    size?: 'small' | 'medium';
    /**
     * The shape of the component.
     *
     * @default 'square'
     */
    shape?: 'circle' | 'square';
    /**
     * If true, the preview will be hidden.
     *
     * @default false
     */
    disablePreview?: boolean;
    /**
     * If true, the open new window button will be hidden.
     *
     * @default false
     */
    enableOpenNewWindow?: boolean;
    /**
     * If true, the image can be deleted.
     *
     * @default true
     */
    deletable?: boolean;
    /**
     * If true, the input will be error state.
     */
    error?: boolean;
    /**
     * The accept file mime types. only start with `'image/'` or `'application/pdf'`.
     *
     * @default ['image/*', 'application/pdf']
     */
    acceptMimeTypes?: string[];
    /**
     * Callback fired when the value is changed.
     *
     * @param event — The event source of the callback.
     * @param newImage — The new file.
     */
    onChange?: (event: object, newImage?: File) => void;
    /**
     * Callback fired when the type is error.
     */
    onTypeError?: () => void;
} & Omit<BoxProps$1, 'onChange'>;
/**
 * `ImageField` 上傳圖片，主要是用來包裝上傳圖片的 input，並提供預覽功能。
 */
declare const ImageField: ({ image: imageOuter, imageName: imageNameOuter, acceptMimeTypes, onChange, onTypeError, size, shape, disablePreview, enableOpenNewWindow, deletable, error, ...rest }: ImageFieldProps) => react_jsx_runtime.JSX.Element;

type ImageInfo = {
    id: number;
} & Required<Pick<ImageFieldProps, 'image'>> & Pick<ImageFieldProps, 'imageName' | 'error' | 'deletable' | 'acceptMimeTypes'>;
type ImageArrayProps = {
    /**
     * The maximum number of images.
     *
     * @default 1
     */
    maxCount?: number;
    /**
     * The images to be displayed.
     */
    images?: ImageInfo[];
    /**
     * The default configuration of the image field.
     */
    defaultConfig?: Pick<ImageFieldProps, 'size' | 'disablePreview' | 'deletable' | 'acceptMimeTypes' | 'error' | 'onTypeError'>;
    /**
     * The callback fired when the value is be added.
     *
     * @param newImage - The new image.
     * @param newImages - The new images.
     */
    onAdd?: (newImage: ImageInfo, newImages: ImageInfo[]) => void;
    /**
     * The callback fired when the value is be deleted.
     *
     * @param id - The id of the image.
     * @param deleteFile - The file to be deleted.
     * @param newImages  - The new images.
     */
    onDelete?: (id: number, deleteFile: ImageInfo, newImages: ImageInfo[]) => void;
};
/**
 * `ImageArray` 將多個 `ImageField` 包裝成陣列，並提供新增、刪除功能。
 */
declare const ImageArray: ({ maxCount, images: imagesOuter, defaultConfig, onAdd, onDelete, }: ImageArrayProps) => react_jsx_runtime.JSX.Element;

type ModalProps = {
    /**
     * The title of the dialog.
     */
    title?: string;
    /**
     * If `true`, will show the close icon button on the top-right corner.
     *
     * @default true
     */
    showCloseIcon?: boolean;
    /**
     * The props of the title wrapper `DialogTitle` component.
     *
     * ref: [DialogTitle API](https://mui.com/material-ui/api/dialog-title/)
     */
    titleProps?: DialogTitleProps;
    /**
     * If `true`, disable clicking on the backdrop to close the modal.
     *
     * @default false
     */
    disableBackdropClick?: boolean;
    /**
     * Callback fired when the component requests to be closed.
     *
     * @param event — The event source of the callback.
     * @param reason — Can be: "escapeKeyDown", "backdropClick", "closeButtonClick".
     */
    onClose?: (event: object, reason: 'backdropClick' | 'escapeKeyDown' | 'closeButtonClick') => void;
    /**
     * The props of the content wrapper `DialogContent` component.
     *
     * ref: [DialogContent API](https://mui.com/material-ui/api/dialog-content/)
     */
    contentProps?: {
        /**
         * Display the top and bottom dividers.
         *
         * @default true
         */
        dividers?: boolean;
    } & Omit<DialogContentProps, 'dividers'>;
    /**
     * The props of the actions wrapper `DialogActions` component.
     *
     * ref: [DialogActions API](https://mui.com/material-ui/api/dialog-actions/)
     */
    actionsProps?: DialogActionsProps;
    /**
     * Callback fired when the submit button is clicked.
     */
    onSubmit?: () => void | Promise<void>;
    /**
     * The text of the submit button.
     *
     * @default 'Submit'
     */
    submitButtonText?: string;
    /**
     * The text of the cancel button.
     *
     * @default 'Cancel'
     */
    cancelButtonText?: string;
    /**
     * Custom actions component.
     */
    customActions?: React.ReactNode;
    /**
     * If `true`, the modal will show loading effect.
     *
     * @default false
     */
    loading?: boolean;
    /**
     * The options of loading effect.
     */
    loadingOptions?: LoadingContentProp;
} & Omit<DialogProps, 'onClose'>;
/**
 * `Modal` 是一個封裝好的對話框元件，提供了標題、內容、確定、取消等功能。
 *
 * 參考 [Material-UI Dialog](https://mui.com/material-ui/react-dialog/)
 */
declare const Modal: react.ForwardRefExoticComponent<Omit<ModalProps, "ref"> & react.RefAttributes<HTMLDivElement>>;

type ModalQuickProps = {
    /**
     * The type of the modal.
     */
    type: 'info' | 'success' | 'warning' | 'error' | 'confirm';
    /**
     * Callback fired when the ok button is clicked.
     */
    onOk?: () => void | Promise<void>;
    /**
     * The text of the ok button.
     *
     * @default 'OK'
     */
    okButtonText?: string;
} & Pick<ModalProps, 'open' | 'title' | 'children' | 'onClose' | 'cancelButtonText'>;

type ModalOptions = {
    modalId: number;
    content: ModalQuickProps['children'];
    onClose?: ModalQuickProps['onClose'];
} & Omit<ModalQuickProps, 'children' | 'onClose'>;

type ModalHostProps = Pick<ModalOptions, 'okButtonText' | 'cancelButtonText'>;
declare const ModalHost: (defaultProps?: ModalHostProps) => react_jsx_runtime.JSX.Element;

type ModalConfig = Omit<ModalOptions, 'modalId' | 'open' | 'type'>;
declare const openModal: {
    /**
     * Show an info modal.
     */
    info: (config: ModalConfig) => void;
    /**
     * Show a success modal.
     */
    success: (config: ModalConfig) => void;
    /**
     * Show a warning modal.
     */
    warning: (config: ModalConfig) => void;
    /**
     * Show an error modal.
     */
    error: (config: ModalConfig) => void;
    /**
     * Show a confirm modal.
     */
    confirm: (config: ModalConfig) => void;
};

declare const easingFunctions: {
    readonly 'ease-out': (progress: number) => number;
    readonly 'ease-in': (progress: number) => number;
    readonly 'ease-in-out': (progress: number) => number;
    readonly linear: (progress: number) => number;
};
type UseNumberIncrement = {
    /**
     * The starting value of the number increment animation.
     *
     * @default 0
     */
    startValue?: number;
    /**
     * The target value to increment to.
     */
    targetValue: number;
    /**
     * The duration of the increment animation in milliseconds.
     *
     * @default 3000
     */
    duration?: number;
    /**
     * The easing function to use for the animation.
     *
     * - If a string is provided, it must be one of the following predefined easing functions:
     *   - `'ease-out'`: Starts fast and slows down at the end.
     *   - `'ease-in'`: Starts slow and speeds up towards the end.
     *   - `'ease-in-out'`: Starts slow, speeds up in the middle, and slows down at the end.
     *   - `'linear'`: Maintains a constant speed throughout the animation.
     *
     * - If a custom function is provided, it must take a `progress` (a number between 0 and 1) as input
     *   and return a new progress value (also between 0 and 1) to define the easing behavior.
     *
     * @default 'ease-out'
     */
    easing?: keyof typeof easingFunctions | ((progress: number) => number);
};
/**
 * A hook that increments a number from 0 to a target value over a specified duration.
 *
 * @returns The current value of the incrementing number.
 */
declare const useNumberIncrement: ({ startValue, targetValue, duration, easing, }: UseNumberIncrement) => number;

type NumberIncrementProps = {
    /**
     * The props applied to the container element Box.
     */
    containerProps?: react__default.ComponentProps<typeof Box>;
    /**
     * The props applied to the text element Typography.
     */
    textProps?: react__default.ComponentProps<typeof Typography>;
    /**
     * Determines how the number is formatted.
     * - If `true`, the number is formatted using the `formatAmount` utility.
     * - If a function is provided, it will be called with the number value to return a custom-formatted string.
     * - If `false`, the raw number will be displayed.
     *
     * Example:
     * ```
     * formatValue={value => `${value}%`}
     * ```
     *
     * @default true
     */
    formatValue?: boolean | ((value: number) => string);
    /**
     * The label to display below the number.
     */
    label?: string;
    /**
     * The props applied to the label element Typography.
     */
    labelProps?: react__default.ComponentProps<typeof Typography>;
} & UseNumberIncrement;
declare const NumberIncrement: react__default.FC<NumberIncrementProps>;

type SidebarMenuButtonProps<C extends React.ElementType> = BoxProps<C, {
    tooltip?: string;
    isActive?: boolean;
    component?: C;
}>;
declare const SidebarMenuButton: <C extends React.ElementType>({ children, sx, tooltip, isActive, ...props }: SidebarMenuButtonProps<C>) => react_jsx_runtime.JSX.Element;
declare const SidebarHeader: ({ sx, children, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;
declare const SidebarMenu: ({ sx, children, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;
declare const SidebarMenuItem: ({ children, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;
declare const SidebarContent: ({ sx, children, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;
declare const SidebarFooter: ({ sx, children, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;
declare const SidebarGroup: ({ sx, children, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;
declare const SidebarGroupLabel: ({ children, sx, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;
declare const SidebarGroupContent: ({ sx, children, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;
declare const SidebarMenuSub: ({ children, sx, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;
declare const SidebarMenuSubItem: ({ children, ...props }: BoxProps) => react_jsx_runtime.JSX.Element;
type SidebarMenuSubButtonProps<C extends React.ElementType> = BoxProps<C, {
    isActive?: boolean;
    component?: C;
}>;
declare const SidebarMenuSubButton: <C extends React.ElementType>({ children, sx, isActive, ...props }: SidebarMenuSubButtonProps<C>) => react_jsx_runtime.JSX.Element;
type SidebarProps = Omit<SwipeableDrawerProps, 'onOpen' | 'onClose' | 'open' | 'variant'>;
declare const Sidebar: ({ children, sx, ...props }: SidebarProps) => react_jsx_runtime.JSX.Element;

type TSidebarContext = {
    open: boolean;
    setOpen: (open: boolean) => void;
    openMobile: boolean;
    setOpenMobile: (open: boolean) => void;
    isMobile: boolean;
    toggleSidebar: () => void;
    width: number;
};
declare const useSidebar: () => TSidebarContext;
type SidebarProviderProps = BoxProps$1 & {
    widthConfig?: {
        width?: number;
        widthIcon?: number;
        widthMobile?: number;
    };
    defaultOpen?: boolean;
    open?: boolean;
    onOpenChange?: (open: boolean) => void;
};
declare const SidebarProvider: react.ForwardRefExoticComponent<Omit<SidebarProviderProps, "ref"> & react.RefAttributes<HTMLDivElement>>;

type SwitchProps = SwitchProps$1;
/**
 * `Switch` 元件是一個開關的選擇器。
 * 在我們表示開關狀態，或兩種狀態之間的切換時，很適合使用。和 Checkbox 的區別是， Checkbox 一般只用來標記狀態是否被選取，
 * 需要提交之後才會生效，而 Switch 則會在觸發的當下直接觸發狀態的改變。
 *
 * 參考 [Material-UI: Switch](https://mui.com/material-ui/react-switch/)
 */
declare const Switch: react.ForwardRefExoticComponent<Omit<SwitchProps$1, "ref"> & react.RefAttributes<HTMLButtonElement>>;

type TableProps<TData extends Record<string, any>> = {
    /**
     * 是否顯示邊框
     */
    bordered?: boolean;
} & Omit<MRT_TableOptions<TData>, 'enableTopToolbar' | 'enableColumnActions' | 'enableDensityToggle'>;
/**
 * `useTable` 是一個自定義的 Hook，用來設定 `Table` 的預設值。
 *
 * 參考 [Material React Table](https://www.material-react-table.com/docs/api/mrt-hooks#usematerialreacttable)
 */
declare const useTable: <TData extends Record<string, any> = []>({ enableSorting, enablePagination, bordered, displayColumnDefOptions, ...rest }: TableProps<TData>) => material_react_table.MRT_TableInstance<TData>;
/**
 * `Table` 顧名思義就是一個表格元件，用來整齊的顯示行列數據。
 *
 * 參考 [Material React Table](https://www.material-react-table.com/)
 */
declare const Table: {
    <TData extends Record<string, any> = []>(tableProps: TableProps<TData>): react_jsx_runtime.JSX.Element;
    displayName: string;
};

type NumberFieldProps = Omit<TextFieldProps$2, 'type' | 'autoComplete' | 'maxRows' | 'multiline' | 'rows' | 'select' | 'SelectProps' | 'inputMode' | 'inputProps'> & NumericFormatProps;
/**
 * `NumberField` 元件代表一個數字輸入框，繼承自 `TextField`。
 *
 * 參考 [React Number Format](https://s-yadav.github.io/react-number-format/)
 */
declare const NumberField: (props: NumberFieldProps) => react_jsx_runtime.JSX.Element;

type TextFieldProps$1 = Omit<TextFieldProps$2, 'onChange' | 'select' | 'multiline' | 'defaultValue' | 'value' | 'autoFocus'>;
declare const OTPField: react.ForwardRefExoticComponent<{
    /**
     * The length of the OTP field.
     *
     * @default 4
     */
    length?: number;
    /**
     * The value of the OTP field.
     */
    value?: string;
    /**
     * The default value of the OTP field.
     */
    defaultValue?: string;
    /**
     * Callback fired when the value is changed.
     *
     * @param newValue The new value.
     */
    onChange?: (newValue: string) => void;
    /**
     * A function to validate the input character when it is entered.
     *
     * @param char the character
     * @param index the index of the character
     */
    validateChar?: (char: string, index: number) => boolean;
    /**
     * The props for the text fields. It will apply to all text fields.
     *
     * If a function is provided, it will be called for each text field with the index of the text field.
     *
     * @example
     *
     * ```tsx
     * <OTPField
     *    TextFieldsProps={{
     *    variant: 'outlined',
     *      size: 'small',
     *  }}
     * />
     * // or specify different props for each text field
     * <OTPField
     *    TextFieldsProps={(index) => {
     *      if (index === 0) {
     *        // first text field
     *      }
     *    }
     * />
     * ```
     */
    TextFieldsProps?: TextFieldProps$1 | ((index: number) => TextFieldProps$1);
} & Omit<BoxProps, "ref" | "defaultValue" | "onBlur" | "onChange"> & Pick<TextFieldProps$2, "autoFocus" | "onBlur"> & react.RefAttributes<unknown>>;

type TextFieldProps<Variant extends TextFieldVariants> = {
    /**
     * If `true`, it will show the button to toggle password visibility.
     *
     * @default false
     */
    allowShowPassword?: boolean;
    /**
     * The placeholder for the select component.
     *
     * @default "please select"
     */
    selectPlaceholder?: string;
    /**
     * If `true`, it will show the button to clear the value.
     *
     * @default false
     */
    allowClear?: boolean;
    /**
     * The variant to use.
     * @default 'outlined'
     */
    variant?: Variant;
} & Omit<TextFieldProps$2, 'variant'>;
/**
 * `TextField` 元件代表一個文字輸入框，也可以用於選擇框，用於須將label呈現在輸入框border上的情況。
 *
 * 參考 [Material-UI Text Field](https://mui.com/material-ui/react-text-field/)
 */
declare const TextField: react.ForwardRefExoticComponent<Omit<TextFieldProps<TextFieldVariants>, "ref"> & react.RefAttributes<HTMLDivElement>>;

type ToastState = {
    /**
     * The props for the `Snackbar` component.
     */
    toastProps?: Omit<SnackbarProps, 'children' | keyof Pick<SnackbarProps, 'key' | 'open' | 'message'>>;
    /**
     * The props for the `Alert` component.
     */
    alertProps?: Omit<AlertProps, 'children' | 'severity'>;
    /**
     * The type of the `Alert` component.
     */
    type: AlertColor;
} & Pick<SnackbarProps, 'key' | 'open' | 'message'>;

type ToasterProps = {
    defaultSnackbarProps?: {
        /**
         * The number of milliseconds to wai0t before automatically calling the onClose function. onClose should then set the state of the open prop to hide the Snackbar.
         *
         * @default { success: 3000, warning: 3000, error: 5000, info: 3000 }
         */
        autoHideDuration?: {
            [key in AlertColor]: number;
        };
        /**
         * The anchor of the Snackbar.
         *
         * @default { vertical: 'top', horizontal: 'center' }
         */
        anchorOrigin?: SnackbarProps['anchorOrigin'];
    } & Omit<ToastState['toastProps'], 'autoHideDuration' | 'anchorOrigin'>;
    defaultAlertProps?: ToastState['alertProps'];
};
/**
 * `Toaster` 用來顯示 Toast 訊息的容器元件，如要使用 `toast` 函式，請確保 `Toaster` 已經被掛載在應用程式的最上層。
 */
declare const Toaster: ({ defaultSnackbarProps, defaultAlertProps }: ToasterProps) => react_jsx_runtime.JSX.Element;

type ToastConfig = Omit<ToastState, 'key' | 'open' | 'type'> & Required<Pick<ToastState, 'message'>>;
/**
 * `toast` 函式用來顯示 Toast 訊息。
 *
 * 提供四種訊息類型：`info`、`success`、`error`、`warning`，分別對應到四種不同的樣式。
 */
declare const toast: {
    /**
     * Info message
     */
    info: (props: ToastConfig) => void;
    /**
     * Success message
     */
    success: (props: ToastConfig) => void;
    /**
     * Error message
     *
     * 無法點擊其他地方關閉，須等待自動關閉
     */
    error: (props: ToastConfig) => void;
    /**
     * Warning message
     */
    warning: (props: ToastConfig) => void;
};

type FileInfo = {
    id: number;
    file: File;
};

type UploadButtonProps = {
    /**
     * The accept file mime types.
     *
     * e.g. 'image/png'、'image/jpg'、'image/*'
     */
    acceptMimeTypes?: string[];
    /**
     * The callback function when the file is added.
     * @param e The event object.
     */
    handleAddFile: (e: React.ChangeEvent<HTMLInputElement>) => void;
    /**
     * The disabled state.
     *
     * @default false
     */
    disabled?: boolean;
    /**
     * The type of upload panel
     *
     * @default 'drag-and-drop'
     */
    type?: 'drag-and-drop' | 'compact-list';
};

type UploadPanelProps = {
    /**
     * The callback function when the file is dropped.
     * @param e The event object.
     */
    handleDropFile: (e: React.DragEvent<HTMLDivElement>) => void;
    /**
     * The disabled state.
     */
    i18n?: {
        /**
         * The main text.
         */
        main?: string;
        /**
         * The sub text.
         */
        sub?: string;
        /**
         * The button text.
         */
        button?: string;
    };
} & Omit<UploadButtonProps, 'icon' | 'type'>;

type UseFileUpload = {
    /**
     * Files
     */
    files?: FileInfo[];
    /**
     * Callback when a new file is added
     *
     * @param newFile - The new file
     * @param newFiles - The new files
     */
    onAddFile?: (newFile: FileInfo, newFiles: FileInfo[]) => void;
    /**
     * Callback when a file is removed
     *
     * @param id - The id of the file
     * @param targetFile - The target file
     * @param newFiles - The new files
     */
    onRemoveFile?: (id: number, targetFile: FileInfo, newFiles: FileInfo[]) => void;
};

type UploadFileProps = {
    /**
     * Maximum number of files
     *
     * @default 1
     */
    maxFiles?: number;
    /**
     * The callback function when type error
     */
    onTypeError?: () => void;
} & UseFileUpload & Pick<UploadPanelProps, 'acceptMimeTypes' | 'i18n'> & Pick<UploadButtonProps, 'type'> & StackProps;
declare const UploadFile: (props: UploadFileProps) => react_jsx_runtime.JSX.Element;

/**
 * 合併 SxProps 物件陣列，並過濾掉 false 和 undefined 的值。
 *
 * @param styles 要合併的 SxProps 物件陣列
 */
declare const mergeSx: <T extends object>(...styles: (SxProps<T> | false | undefined)[]) => SxProps<T>;
declare const serverOnlySx: () => SxProps;

export { BreadcrumbItem, Breadcrumbs, BreadcrumbsProvider, Button, Card, Carousel, CarouselContent, CarouselItem, CarouselNext, CarouselPrevious, Collapsible, CollapsibleContent, CollapsibleIcon, CollapsibleTrigger, DecorativeTitle, Dot, Drawer, DropDown, DropDownList, FormItem, IconButton, ImageArray, ImageField, LoadingContent, LoadingFullScreen, LoadingIndicator, Modal, ModalHost, NumberField, NumberIncrement, OTPField, Sidebar, SidebarContent, SidebarFooter, SidebarGroup, SidebarGroupContent, SidebarGroupLabel, SidebarHeader, SidebarMenu, SidebarMenuButton, SidebarMenuItem, SidebarMenuSub, SidebarMenuSubButton, SidebarMenuSubItem, SidebarProvider, Switch, Table, TextField, Toaster, UploadFile, mergeSx, openModal, serverOnlySx, toast, useBreadcrumbs, useCarousel, useCollapsible, useNumberIncrement, useSidebar, useTable };
export type { BreadcrumbItemProps, BreadcrumbsProps, ButtonProps, CardProps, CarouselProps, DecorativeTitleProps, DotProps, DrawerProps, DropDownListProps, DropDownProps, FileInfo, FormItemProps, IconButtonProps, ImageArrayProps, ImageFieldProps, ImageInfo, LoadingContentProp, LoadingFullScreenProps, LoadingIndicatorProps, ModalConfig, ModalHostProps, NumberFieldProps, NumberIncrementProps, SidebarMenuButtonProps, SidebarMenuSubButtonProps, SwitchProps, TBreadcrumbsContext, TCollapsibleContext, TCollapsibleProvider, TableProps, TextFieldProps, ToastConfig, ToasterProps };
