'use client';
import { jsx } from 'react/jsx-runtime';
import { Box } from '@mui/material';
import useEmblaCarousel from 'embla-carousel-react';
import { useContext, createContext, useState, useCallback, useEffect, useMemo } from 'react';
import { m as mergeSx } from './Button-12s-CYbIRpne.mjs';

const CarouselContext = /*#__PURE__*/ createContext(null);
const useCarousel = ()=>{
    const context = useContext(CarouselContext);
    if (!context) {
        throw new Error('useCarousel must be used within a <Carousel />');
    }
    return context;
};
/**
 * 一個基於 Embla Carousel 的 Carousel 元件，通常用於展示多個元素，並提供左右滑動的功能。
 *
 * 參考 [Embla Carousel](https://www.embla-carousel.com/)
 *
 * @example
 *
 * ```tsx
 * <Carousel>
 *  <CarouselContent>
 *   {Array.from({ length: 5 }).map((_, index) => (
 *    <CarouselItem key={index}>
 *      {index + 1}
 *    </CarouselItem>
 *   ))}
 *  </CarouselContent>
 *  <CarouselPrevious />
 *  <CarouselNext />
 * </Carousel>
 * ```
 */ const Carousel = ({ orientation = 'horizontal', opts, setApi, plugins, className, children, sx, ...props })=>{
    const [carouselRef, api] = useEmblaCarousel({
        ...opts,
        axis: orientation === 'horizontal' ? 'x' : 'y'
    }, plugins);
    const [canScrollPrev, setCanScrollPrev] = useState(false);
    const [canScrollNext, setCanScrollNext] = useState(false);
    const onSelect = useCallback((_api)=>{
        if (!_api) return;
        setCanScrollPrev(_api.canScrollPrev());
        setCanScrollNext(_api.canScrollNext());
    }, []);
    const scrollPrev = useCallback(()=>{
        api?.scrollPrev();
    }, [
        api
    ]);
    const scrollNext = useCallback(()=>{
        api?.scrollNext();
    }, [
        api
    ]);
    const handleKeyDown = useCallback((event)=>{
        if (event.key === 'ArrowLeft') {
            event.preventDefault();
            scrollPrev();
        } else if (event.key === 'ArrowRight') {
            event.preventDefault();
            scrollNext();
        }
    }, [
        scrollPrev,
        scrollNext
    ]);
    useEffect(()=>{
        if (!api || !setApi) return;
        setApi(api);
    }, [
        api,
        setApi
    ]);
    useEffect(()=>{
        if (!api) return undefined;
        onSelect(api);
        api.on('reInit', onSelect);
        api.on('select', onSelect);
        return ()=>{
            api?.off('select', onSelect);
        };
    }, [
        api,
        onSelect
    ]);
    const contextValue = useMemo(()=>({
            carouselRef,
            api,
            opts,
            orientation: orientation || (opts?.axis === 'y' ? 'vertical' : 'horizontal'),
            scrollPrev,
            scrollNext,
            canScrollPrev,
            canScrollNext
        }), [
        api,
        canScrollNext,
        canScrollPrev,
        carouselRef,
        opts,
        orientation,
        scrollNext,
        scrollPrev
    ]);
    return /*#__PURE__*/ jsx(CarouselContext.Provider, {
        value: contextValue,
        children: /*#__PURE__*/ jsx(Box, {
            onKeyDownCapture: handleKeyDown,
            sx: mergeSx({
                position: 'relative'
            }, sx),
            role: "region",
            "aria-roledescription": "carousel",
            ...props,
            children: children
        })
    });
};

export { Carousel as C, useCarousel as u };
