'use client';
import { jsx } from 'react/jsx-runtime';
import { Popper, Fade, Paper, ClickAwayListener, Box } from '@mui/material';
import { m as mergeSx } from './Button-12s-CYbIRpne.mjs';

/**
 * 用於下拉式區域的 Popper。
 *
 * 參考 [Material-UI Popper](https://mui.com/material-ui/react-popper/)
 *
 * @example
 *
 * ```tsx
 * <Button ref={anchorRef} onClick={() => setOpen(true)}>
 *   Open
 * </Button>
 * <DropDown
 *  open={open}
 *  onClose={() => setOpen(false)}
 *  anchorRef={anchorRef}
 * >
 *  content
 * </DropDown>
 * ```
 */ const DropDown = ({ open, anchorRef, onClose, paperProps, children, ...props })=>{
    const handleClose = (event)=>{
        if (anchorRef?.current && anchorRef.current.contains(event.target)) {
            return;
        }
        onClose?.();
    };
    return /*#__PURE__*/ jsx(Popper, {
        placement: "bottom-end",
        ...props,
        open: open,
        anchorEl: anchorRef?.current,
        transition: true,
        children: ({ TransitionProps })=>/*#__PURE__*/ jsx(Fade, {
                ...TransitionProps,
                children: /*#__PURE__*/ jsx(Paper, {
                    elevation: 0,
                    ...paperProps,
                    sx: mergeSx({
                        border: 1,
                        borderColor: 'divider',
                        borderRadius: 4
                    }, paperProps?.sx),
                    children: /*#__PURE__*/ jsx(ClickAwayListener, {
                        onClickAway: handleClose,
                        children: /*#__PURE__*/ jsx(Box, {
                            children: children
                        })
                    })
                })
            })
    });
};

export { DropDown as D };
