'use client';
import { jsxs, jsx } from 'react/jsx-runtime';
import Stack from '@mui/material/Stack';
import { useState, useEffect } from 'react';
import { I as ImageField } from './ImageField-12s-D2NcD3HG.mjs';

/**
 * `ImageArray` 將多個 `ImageField` 包裝成陣列，並提供新增、刪除功能。
 */ const ImageArray = ({ maxCount = 1, images: imagesOuter, defaultConfig, onAdd, onDelete })=>{
    const [images, setImages] = useState(imagesOuter ?? []);
    useEffect(()=>{
        setImages(imagesOuter ?? []);
    }, [
        imagesOuter
    ]);
    const handleAddImage = (_, newImage)=>{
        if (!newImage) {
            return;
        }
        const newImageInfo = {
            id: Date.now(),
            image: newImage,
            imageName: newImage.name
        };
        if (onAdd) {
            onAdd(newImageInfo, [
                ...images,
                newImageInfo
            ]);
            return;
        }
        setImages((prevImages)=>[
                ...prevImages,
                newImageInfo
            ]);
    };
    const handleDeleteImage = (id)=>{
        if (onDelete) {
            const deleteFile = images.find((image)=>image.id === id);
            if (!deleteFile) {
                return;
            }
            onDelete(id, deleteFile, images.filter((image)=>image.id !== id));
            return;
        }
        setImages((prevImages)=>prevImages.filter((image)=>image.id !== id));
    };
    return /*#__PURE__*/ jsxs(Stack, {
        direction: "row",
        alignItems: "center",
        gap: 1,
        flexWrap: "wrap",
        children: [
            images.map(({ id, ...imageRest })=>/*#__PURE__*/ jsx(ImageField, {
                    ...defaultConfig,
                    ...imageRest,
                    onChange: (_, newImage)=>{
                        if (!newImage) {
                            handleDeleteImage(id);
                        }
                    }
                }, id)),
            maxCount > images.length && /*#__PURE__*/ jsx(ImageField, {
                ...defaultConfig,
                onChange: handleAddImage
            })
        ]
    });
};

export { ImageArray as I };
