'use client';
import { jsx, jsxs, Fragment } from 'react/jsx-runtime';
import { validateFileType } from '@gateweb/react-utils';
import { OpenInNew, DeleteOutlined, Add } from '@mui/icons-material';
import Box from '@mui/material/Box';
import Stack from '@mui/material/Stack';
import { useState, useMemo, useEffect } from 'react';
import { m as mergeSx } from './Button-12s-CYbIRpne.mjs';
import '@mui/material/Button';
import '@mui/material/CircularProgress';
import { I as IconButton } from './IconButton-12s-Bv2Js2lR.mjs';
import { P as PreviewModal } from './PreviewModal-12s-UG0RHlM0.mjs';

const PDF_MIME_TYPE = 'application/pdf';
/**
 * `ImageField` 上傳圖片，主要是用來包裝上傳圖片的 input，並提供預覽功能。
 */ const ImageField = ({ image: imageOuter, imageName: imageNameOuter, acceptMimeTypes = [
    'image/*',
    PDF_MIME_TYPE
], onChange, onTypeError, size = 'medium', shape = 'square', disablePreview = false, enableOpenNewWindow = true, deletable = true, error, ...rest })=>{
    const [image, setImage] = useState(imageOuter);
    const acceptImageMimeTypes = useMemo(()=>acceptMimeTypes.filter((mimeType)=>mimeType.startsWith('image/') || mimeType === PDF_MIME_TYPE), [
        acceptMimeTypes
    ]);
    useEffect(()=>{
        setImage(imageOuter);
    }, [
        imageOuter
    ]);
    const handleChange = (e)=>{
        if (!e.target.files || e.target.files.length === 0) return;
        const file = e.target.files[0];
        if (!validateFileType(file, acceptImageMimeTypes)) {
            onTypeError?.();
            return;
        }
        if (onChange) {
            onChange(e, file);
            return;
        }
        setImage(file);
    // onChange?.(e, file);
    };
    const handleDelete = ()=>{
        if (onChange) {
            onChange({}, undefined);
            return;
        }
        setImage(undefined);
    // onChange?.({}, undefined);
    };
    const isPdfFile = useMemo(()=>{
        if (!image) return false;
        if (typeof image === 'string') return image.includes('.pdf');
        return image.type === PDF_MIME_TYPE;
    }, [
        image
    ]);
    const imageUrl = useMemo(()=>{
        if (typeof image === 'string') return image;
        if (!image) return undefined;
        return URL.createObjectURL(isPdfFile ? new Blob([
            image
        ], {
            type: `${PDF_MIME_TYPE};charset=utf-8`
        }) : image);
    }, [
        image,
        isPdfFile
    ]);
    const imageName = useMemo(()=>{
        if (imageNameOuter) return imageNameOuter;
        if (typeof image === 'string') return image.split('/').pop();
        return image?.name;
    }, [
        image,
        imageNameOuter
    ]);
    return /*#__PURE__*/ jsx(Box, {
        ...rest,
        sx: mergeSx({
            p: image ? 1 : 0,
            border: 2,
            borderStyle: image ? 'solid' : 'dashed',
            borderRadius: shape === 'square' ? 4 : '50%',
            borderColor: error ? 'error.main' : 'divider',
            width: size === 'small' ? 80 : 100,
            height: size === 'small' ? 80 : 100,
            overflow: 'hidden',
            aspectRatio: '1/1',
            position: 'relative',
            backgroundColor: 'background.paper',
            '&:hover': {
                ...!image && {
                    borderColor: 'primary.main'
                },
                '& .action': {
                    opacity: 1
                }
            }
        }, rest?.sx),
        children: image ? /*#__PURE__*/ jsxs(Fragment, {
            children: [
                /*#__PURE__*/ jsx(Box, {
                    component: "div",
                    className: "action",
                    sx: {
                        position: 'absolute',
                        background: 'rgba(0, 0, 0, 0.45)',
                        width: 'calc(100% - 16px)',
                        height: 'calc(100% - 16px)',
                        borderRadius: shape === 'square' ? undefined : '50%',
                        opacity: 0,
                        transition: 'opacity 0.3s ease-in-out'
                    },
                    children: /*#__PURE__*/ jsxs(Stack, {
                        direction: "row",
                        justifyContent: "center",
                        alignItems: "center",
                        height: "100%",
                        flexWrap: "wrap",
                        children: [
                            !disablePreview && /*#__PURE__*/ jsx(PreviewModal, {
                                imageUrl: imageUrl,
                                title: imageName,
                                pdf: isPdfFile
                            }),
                            enableOpenNewWindow && /*#__PURE__*/ jsx(IconButton, {
                                component: "a",
                                size: "small",
                                sx: {
                                    color: '#fff'
                                },
                                href: imageUrl,
                                target: "_blank",
                                "aria-label": "open in new window",
                                children: /*#__PURE__*/ jsx(OpenInNew, {})
                            }),
                            deletable && /*#__PURE__*/ jsx(IconButton, {
                                size: "small",
                                sx: {
                                    color: '#fff'
                                },
                                onClick: handleDelete,
                                "aria-label": "delete",
                                children: /*#__PURE__*/ jsx(DeleteOutlined, {})
                            })
                        ]
                    })
                }),
                isPdfFile ? /*#__PURE__*/ jsx(Box, {
                    component: "iframe",
                    src: `${imageUrl}#toolbar=0`,
                    width: "100%",
                    height: "100%",
                    title: imageName,
                    sx: {
                        '*': {
                            msOverflowStyle: 'none',
                            '&::-webkit-scrollbar': {
                                display: 'none'
                            }
                        }
                    }
                }) : /*#__PURE__*/ jsx(Box, {
                    component: "img",
                    src: imageUrl,
                    alt: imageName,
                    sx: {
                        width: '100%',
                        height: '100%',
                        objectFit: 'contain'
                    }
                })
            ]
        }) : /*#__PURE__*/ jsxs(Box, {
            component: "label",
            sx: {
                display: 'flex',
                flexDirection: 'column',
                alignItems: 'center',
                justifyContent: 'center',
                borderRadius: shape === 'square' ? undefined : '50%',
                height: '100%',
                cursor: 'pointer'
            },
            children: [
                /*#__PURE__*/ jsx(Add, {
                    sx: {
                        color: 'divider'
                    }
                }),
                /*#__PURE__*/ jsx(Box, {
                    component: "input",
                    type: "file",
                    onClick: (e)=>{
                        e.target.value = '';
                        e.stopPropagation();
                    },
                    sx: {
                        clip: 'rect(0 0 0 0)',
                        clipPath: 'inset(50%)',
                        height: 1,
                        overflow: 'hidden',
                        position: 'absolute',
                        bottom: 0,
                        left: 0,
                        whiteSpace: 'nowrap',
                        width: 1
                    },
                    onChange: handleChange,
                    accept: acceptImageMimeTypes?.join(','),
                    role: "textbox",
                    "aria-label": "upload"
                })
            ]
        })
    });
};

export { ImageField as I };
